#!/bin/sh

# This is the server-side sound script for LTSP-4.1.  It will setup your
# environment to feed a sound stream to the LTSP client.
#
# This was originally written by Andrew Williams, but has been modified
# by Richard June and James McQuillan to work with LTSP-4.1.
#
# This package is released under the auspices of the GPL
# Copyright (c) 2002 by Andrew Williams (Vartech Solutions)
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESSED OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# VARTECH SOLUTIONS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
# OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
################################################################################
# We support ESD and NAS directly, MAS support is planned next. If you want to #
#   use arts with ltsp, you need to use NAS, then tell arts to output to NAS   #
#   for full information, see http://www.ltsp.org/sound/                       #
################################################################################

DOMAIN=`dnsdomainname`
MYNAME=`echo $DISPLAY | cut -d: -f1 | sed s/\\\.${DOMAIN}//`

if [ -n "${MYNAME}" -a "${MYNAME}" != "localhost" ]; then
  #
  # Usage:  get_cfg PARM [DEFAULT]
  #
  function get_cfg(){
    VALUE=`/usr/bin/ltspinfo \
               -h ${MYNAME}      \
               -c $1`
    if [ "$#" -gt 1 -a -z "${VALUE}" ]; then
      echo $2
    else
      echo ${VALUE}
    fi
	
    unset VALUE
  }

  eval `get_cfg SOUND`
  if [ "$LTSP_SOUND" = "Y" ] ; then
    eval `get_cfg SOUND_DAEMON`
    case "${LTSP_SOUND_DAEMON}" in
      esd)   REMOTESOUNDIP=`echo $DISPLAY | cut -d: -f1`
             REMOTESOUNDPORT="16001"
             LIBESDPATH="/usr/lib/libesd.so.0"
             LIBESDDSPPATH="/usr/lib/libesddsp.so.0"

             #
             # if netcat is installed, we'll check to see if the
             # terminal is listening
             #
             if [ "$REMOTESOUNDIP" -a -x "`which nc 2> /dev/null`" ]; then
               NC=`/usr/bin/nc -v -w 1 -z $REMOTESOUNDIP $REMOTESOUNDPORT 2>&1 \
                   | grep -v open$`
               if [ "${NC}" ]; then
                 #
                 # netcat says the terminal is not listening, bail!
                 #
                 unset REMOTESOUNDIP
                 unset REMOTESOUNDPORT
                 unset LIBESDPATH
                 unset LIBESDDSPPATH
               fi
             fi

             #
             # don't use this hack for local X sessions, root, and only if
             # the pre-load libraries are found
             #
             if [      "${REMOTESOUNDIP}" \
                 -a -x "$LIBESDPATH"      \
                 -a -x "$LIBESDDSPPATH" ]
             then
               export ESPEAKER=${REMOTESOUNDIP}:16001
               export ESDDSP_MIXER=1
               export LD_PRELOAD="$LIBESDPATH $LIBESDDSPPATH"
               /usr/bin/esdctl unlock
             fi
             #
             # clean up temporary variables
             #
             unset REMOTESOUNDIP
             unset REMOTESOUNDPORT
             unset LIBESDPATH
             unset LIBESDDSPPATH
             ;;

      nasd)  LIBAUDIO=/usr/X11R6/lib/libaudiooss.so.1
             if [ -f ${LIBAUDIO} ]; then
               if [ `echo "${LD_PRELOAD}" | grep -c ${LIBAUDIO}` ]; then
                 export LD_PRELOAD="${LIBAUDIO}"
               else
                 export LD_PRELOAD="${LIBAUDIO} ${LD_PRELOAD}"
               fi
             fi
             export AUDIOSERVER="$DISPLAY"

             #
             # Uncomment the following to enable this to work with "wine"
             # This also works well with the Linux ICA client.
             #    export AUDIOOSS_WINE_HACK="y"
             ;;

      rplay) export LD_PRELOAD="/usr/local/lib/devrplay.so"
             ;;

      *)     #
             # No more options available get on with Life
             #
             ;;
    esac
  fi
fi

unset DOMAIN
unset MYNAME
unset get_cfg
